==> libgit2-glib-0.0.2.tar.xz: libgit2-glib-0.0.2/libgit2-glib/ggit-enum-types.h <==

/* Generated data (by glib-mkenums) */

#ifndef __GGIT_ENUM_TYPES_H__
#define __GGIT_ENUM_TYPES_H__

#include <glib-object.h>

G_BEGIN_DECLS

/* Enumerations from "ggit-types.h" */

#define GGIT_TYPE_BRANCH_TYPE	(ggit_branch_type_get_type())
GType ggit_branch_type_get_type	(void) G_GNUC_CONST;

#define GGIT_TYPE_CAP_FLAGS	(ggit_cap_flags_get_type())
GType ggit_cap_flags_get_type	(void) G_GNUC_CONST;

#define GGIT_TYPE_CONFIG_LEVEL	(ggit_config_level_get_type())
GType ggit_config_level_get_type	(void) G_GNUC_CONST;

#define GGIT_TYPE_CREATE_FLAGS	(ggit_create_flags_get_type())
GType ggit_create_flags_get_type	(void) G_GNUC_CONST;

#define GGIT_TYPE_DELTA_TYPE	(ggit_delta_type_get_type())
GType ggit_delta_type_get_type	(void) G_GNUC_CONST;

#define GGIT_TYPE_DIFF_OPTION	(ggit_diff_option_get_type())
GType ggit_diff_option_get_type	(void) G_GNUC_CONST;

#define GGIT_TYPE_DIFF_FLAG	(ggit_diff_flag_get_type())
GType ggit_diff_flag_get_type	(void) G_GNUC_CONST;

#define GGIT_TYPE_DIFF_LINE_TYPE	(ggit_diff_line_type_get_type())
GType ggit_diff_line_type_get_type	(void) G_GNUC_CONST;

#define GGIT_TYPE_ERROR	(ggit_error_get_type())
GType ggit_error_get_type	(void) G_GNUC_CONST;

#define GGIT_TYPE_FILE_MODE	(ggit_file_mode_get_type())
GType ggit_file_mode_get_type	(void) G_GNUC_CONST;

#define GGIT_TYPE_REMOTE_DOWNLOAD_TAGS_TYPE	(ggit_remote_download_tags_type_get_type())
GType ggit_remote_download_tags_type_get_type	(void) G_GNUC_CONST;

#define GGIT_TYPE_REF_TYPE	(ggit_ref_type_get_type())
GType ggit_ref_type_get_type	(void) G_GNUC_CONST;

#define GGIT_TYPE_RESET_TYPE	(ggit_reset_type_get_type())
GType ggit_reset_type_get_type	(void) G_GNUC_CONST;

#define GGIT_TYPE_SORT_MODE	(ggit_sort_mode_get_type())
GType ggit_sort_mode_get_type	(void) G_GNUC_CONST;

#define GGIT_TYPE_STASH_FLAGS	(ggit_stash_flags_get_type())
GType ggit_stash_flags_get_type	(void) G_GNUC_CONST;

#define GGIT_TYPE_STATUS_FLAGS	(ggit_status_flags_get_type())
GType ggit_status_flags_get_type	(void) G_GNUC_CONST;

#define GGIT_TYPE_SUBMODULE_IGNORE	(ggit_submodule_ignore_get_type())
GType ggit_submodule_ignore_get_type	(void) G_GNUC_CONST;

#define GGIT_TYPE_SUBMODULE_STATUS	(ggit_submodule_status_get_type())
GType ggit_submodule_status_get_type	(void) G_GNUC_CONST;

#define GGIT_TYPE_SUBMODULE_UPDATE	(ggit_submodule_update_get_type())
GType ggit_submodule_update_get_type	(void) G_GNUC_CONST;

#define GGIT_TYPE_TREE_WALK_MODE	(ggit_tree_walk_mode_get_type())
GType ggit_tree_walk_mode_get_type	(void) G_GNUC_CONST;

G_END_DECLS

#endif /* __GGIT_ENUM_TYPES_H__ */

/* Generated data ends here */

==> libgit2-glib-0.0.4.tar.xz: libgit2-glib-0.0.4/libgit2-glib/ggit-enum-types.h <==

/* Generated data (by glib-mkenums) */

#ifndef __GGIT_ENUM_TYPES_H__
#define __GGIT_ENUM_TYPES_H__

#include <glib-object.h>

G_BEGIN_DECLS

/* Enumerations from "ggit-types.h" */

#define GGIT_TYPE_BRANCH_TYPE	(ggit_branch_type_get_type())
GType ggit_branch_type_get_type	(void) G_GNUC_CONST;

#define GGIT_TYPE_CAP_FLAGS	(ggit_cap_flags_get_type())
GType ggit_cap_flags_get_type	(void) G_GNUC_CONST;

#define GGIT_TYPE_CONFIG_LEVEL	(ggit_config_level_get_type())
GType ggit_config_level_get_type	(void) G_GNUC_CONST;

#define GGIT_TYPE_CREATE_FLAGS	(ggit_create_flags_get_type())
GType ggit_create_flags_get_type	(void) G_GNUC_CONST;

#define GGIT_TYPE_DELTA_TYPE	(ggit_delta_type_get_type())
GType ggit_delta_type_get_type	(void) G_GNUC_CONST;

#define GGIT_TYPE_DIFF_OPTION	(ggit_diff_option_get_type())
GType ggit_diff_option_get_type	(void) G_GNUC_CONST;

#define GGIT_TYPE_DIFF_FLAG	(ggit_diff_flag_get_type())
GType ggit_diff_flag_get_type	(void) G_GNUC_CONST;

#define GGIT_TYPE_DIFF_LINE_TYPE	(ggit_diff_line_type_get_type())
GType ggit_diff_line_type_get_type	(void) G_GNUC_CONST;

#define GGIT_TYPE_ERROR	(ggit_error_get_type())
GType ggit_error_get_type	(void) G_GNUC_CONST;

#define GGIT_TYPE_FILE_MODE	(ggit_file_mode_get_type())
GType ggit_file_mode_get_type	(void) G_GNUC_CONST;

#define GGIT_TYPE_REMOTE_DOWNLOAD_TAGS_TYPE	(ggit_remote_download_tags_type_get_type())
GType ggit_remote_download_tags_type_get_type	(void) G_GNUC_CONST;

#define GGIT_TYPE_REF_TYPE	(ggit_ref_type_get_type())
GType ggit_ref_type_get_type	(void) G_GNUC_CONST;

#define GGIT_TYPE_RESET_TYPE	(ggit_reset_type_get_type())
GType ggit_reset_type_get_type	(void) G_GNUC_CONST;

#define GGIT_TYPE_SORT_MODE	(ggit_sort_mode_get_type())
GType ggit_sort_mode_get_type	(void) G_GNUC_CONST;

#define GGIT_TYPE_STASH_FLAGS	(ggit_stash_flags_get_type())
GType ggit_stash_flags_get_type	(void) G_GNUC_CONST;

#define GGIT_TYPE_STATUS_FLAGS	(ggit_status_flags_get_type())
GType ggit_status_flags_get_type	(void) G_GNUC_CONST;

#define GGIT_TYPE_SUBMODULE_IGNORE	(ggit_submodule_ignore_get_type())
GType ggit_submodule_ignore_get_type	(void) G_GNUC_CONST;

#define GGIT_TYPE_SUBMODULE_STATUS	(ggit_submodule_status_get_type())
GType ggit_submodule_status_get_type	(void) G_GNUC_CONST;

#define GGIT_TYPE_SUBMODULE_UPDATE	(ggit_submodule_update_get_type())
GType ggit_submodule_update_get_type	(void) G_GNUC_CONST;

#define GGIT_TYPE_TREE_WALK_MODE	(ggit_tree_walk_mode_get_type())
GType ggit_tree_walk_mode_get_type	(void) G_GNUC_CONST;

#define GGIT_TYPE_STATUS_OPTION	(ggit_status_option_get_type())
GType ggit_status_option_get_type	(void) G_GNUC_CONST;

#define GGIT_TYPE_STATUS_SHOW	(ggit_status_show_get_type())
GType ggit_status_show_get_type	(void) G_GNUC_CONST;

G_END_DECLS

#endif /* __GGIT_ENUM_TYPES_H__ */

/* Generated data ends here */
